﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
//using System.Windows.Shapes;
using System.IO;

namespace NotatnikWPF
{
    /// <summary>
    /// Logika interakcji dla klasy MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private OpenFileDialog openFileDialog;
        private SaveFileDialog saveFileDialog;

        private string ścieżkaPliku = null;
        private bool czyTekstZmieniony = false;

        public MainWindow()
        {
            InitializeComponent();

            openFileDialog = new OpenFileDialog();
            openFileDialog.Title = "Otwórz plik tekstowy";
            openFileDialog.DefaultExt = "txt";
            openFileDialog.Filter = "Pliki tekstowe (*.txt)|*.txt|Pliki XML (*.xml)|*.xml|Pliki C# (*.cs)|*.cs|Wszystkie pliki (*.*)|*.*";
            openFileDialog.FilterIndex = 1;

            saveFileDialog = new SaveFileDialog();
            saveFileDialog.Title = "Zapisz plik tekstowy";
            saveFileDialog.DefaultExt = "txt";
            saveFileDialog.Filter = openFileDialog.Filter;
            saveFileDialog.FilterIndex = 1;
        }

        private void OtwórzMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (!string.IsNullOrEmpty(ścieżkaPliku))
            {
                openFileDialog.InitialDirectory = Path.GetDirectoryName(ścieżkaPliku);
                openFileDialog.FileName = Path.GetFileName(ścieżkaPliku);
            }

            bool? wynik = openFileDialog.ShowDialog();
            if (wynik.HasValue && wynik.Value)
            {
                ścieżkaPliku = openFileDialog.FileName;
                textBox.Text = File.ReadAllText(ścieżkaPliku);
                statusBarText.Text = Path.GetFileName(ścieżkaPliku);
                czyTekstZmieniony = false;
            }
        }

        private void ZapiszJakoMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (!string.IsNullOrEmpty(ścieżkaPliku))
            {
                saveFileDialog.InitialDirectory = Path.GetDirectoryName(ścieżkaPliku);
                saveFileDialog.FileName = Path.GetFileName(ścieżkaPliku);
            }

            bool? wynik = saveFileDialog.ShowDialog();
            if(wynik.HasValue && wynik.Value)
            {
                ścieżkaPliku = saveFileDialog.FileName;
                File.WriteAllText(ścieżkaPliku, textBox.Text);
                statusBarText.Text = Path.GetFileName(ścieżkaPliku);
                czyTekstZmieniony = false;
            }
        }

        private void ZapiszMenuItem_Click(object sender, RoutedEventArgs e)
        {
            if (!string.IsNullOrEmpty(ścieżkaPliku))
            {
                File.WriteAllText(ścieżkaPliku, textBox.Text);
                czyTekstZmieniony = false;
            }
            else ZapiszJakoMenuItem_Click(sender, e);
        }

        private void ZakończMenuItem_Click(object sender, RoutedEventArgs e)
        {
            Close();
        }

        private void textBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            czyTekstZmieniony = true;
        }

        private void zapytajOZapisanieTekstuDoPliku(object sender, out bool anuluj)
        {
            anuluj = false;
            if (czyTekstZmieniony)
            {
                MessageBoxResult wynik =
                    MessageBox.Show(
                        "Czy zapisać zmiany w edytowanym dokumencie?",
                        this.Title,
                        MessageBoxButton.YesNoCancel,
                        MessageBoxImage.Question,
                        MessageBoxResult.Cancel);

                switch (wynik)
                {
                    case MessageBoxResult.Yes:
                        ZapiszMenuItem_Click(sender, null);
                        break;
                    case MessageBoxResult.No:
                        break;
                    case MessageBoxResult.Cancel:
                        anuluj = true;
                        break;
                }
            }
        }

        private void Window_Closing(object sender, System.ComponentModel.CancelEventArgs e)
        {
            bool anuluj;
            zapytajOZapisanieTekstuDoPliku(sender, out anuluj);
            e.Cancel = anuluj;
        }

        private void NowyMenuItem_Click(object sender, RoutedEventArgs e)
        {
            bool anuluj;
            zapytajOZapisanieTekstuDoPliku(sender, out anuluj);
            if(!anuluj) textBox.Text = "";
        }
    }
}
